@@ -1,6 +1,8 @@
 from django.urls import resolve, Resolver404
 from urllib.parse import urljoin
 
+from . import app_settings
+
 
 class Breadcrumbs:
     def __init__(self, base_url="", path=None):
@@ -24,15 +26,40 @@ class Breadcrumbs:
             path = path[:-1]
         if path.startswith("/"):
             path = path[1:]
+
+        # avoid splitting and returning a list with an empty string
+        if path == "":
+            return list()
+
         result = path.split("/")
         return result
 
+    def _add_home(self):
+        b_item = BreadcrumbsItem(
+            base_url=self.base_url,
+            name_raw=app_settings.DYNAMIC_BREADCRUMBS_HOME_LABEL,
+            path="/",
+            position=1,
+        )
+        self.items.append(b_item)
+
     def _fill_items(self):
         path = "/"
-        for i, item in enumerate(self._split_path()):
+        parts = self._split_path()
+
+        # add home
+        # if have to show home item, and location is home, shows it
+        # or if location is not home, always shows home in breadcrumbs
+        if (app_settings.DYNAMIC_BREADCRUMBS_SHOW_AT_BASE_PATH and not parts) or parts:
+            self._add_home()
+
+        if parts == []:
+            return
+
+        for i, item in enumerate(parts):
             path = urljoin(path, item + "/")
             b_item = BreadcrumbsItem(
-                base_url=self.base_url, name_raw=item, path=path, position=i + 1
+                base_url=self.base_url, name_raw=item, path=path, position=i + 2
             )
             self.items.append(b_item)
 
