@@ -2,6 +2,7 @@ from django.test import TestCase, override_settings
 
 from dynamic_breadcrumbs.utils import Breadcrumbs, BreadcrumbsItem
 from tests.models import Continent, Country, City
+from dynamic_breadcrumbs import app_settings
 
 
 @override_settings(ROOT_URLCONF="tests.urls")
@@ -37,14 +38,22 @@ class BreadcrumbsTests(GenericModelTestCase):
 
         self.assertEqual(paths, expected_result)
 
-    def test_process_all_paths(self):
+    def test_split_path_returns_empty_list(self):
+        path = "/"
+        expected_result = []
+
+        paths = Breadcrumbs()._split_path(path=path)
+
+        self.assertEqual(paths, expected_result)
+
+    def test_process_all_paths_including_home(self):
         base_url = "https://example.com"
         path = "/scale/minor-scale/c"
         breadcrumbs = Breadcrumbs(base_url=base_url, path=path)
 
         result = breadcrumbs.get_items()
 
-        self.assertEqual(len(result), 3)
+        self.assertEqual(len(result), 4)
 
     def test_as_list(self):
         path = "/continent/some-continent/"
@@ -52,10 +61,47 @@ class BreadcrumbsTests(GenericModelTestCase):
 
         result = breadcrumbs.as_list()
 
-        self.assertEqual(result[0]["name"], "continent")
+        self.assertEqual(result[0]["name"], app_settings.DYNAMIC_BREADCRUMBS_HOME_LABEL)
         self.assertEqual(result[0]["resolved"], True)
-        self.assertEqual(result[1]["name"], "some-continent")
+        self.assertEqual(result[1]["name"], "continent")
         self.assertEqual(result[1]["resolved"], True)
+        self.assertEqual(result[2]["name"], "some-continent")
+        self.assertEqual(result[2]["resolved"], True)
+
+    def test_as_list_only_home(self):
+        app_settings.DYNAMIC_BREADCRUMBS_SHOW_AT_BASE_PATH = True
+        path = "/"
+        breadcrumbs = Breadcrumbs(path=path)
+
+        result = breadcrumbs.as_list()
+
+        self.assertEqual(len(result), 1)
+
+    def test_as_list_not_showing_at_home(self):
+        app_settings.DYNAMIC_BREADCRUMBS_SHOW_AT_BASE_PATH = False
+        path = "/"
+        breadcrumbs = Breadcrumbs(path=path)
+
+        result = breadcrumbs.as_list()
+
+        self.assertEqual(len(result), 0)
+
+    def test_show_home_at_base_url(self):
+        app_settings.DYNAMIC_BREADCRUMBS_SHOW_AT_BASE_PATH = True
+        path = "/"
+        breadcrumbs = Breadcrumbs(path=path)
+        result = breadcrumbs.as_list()
+
+        self.assertEqual(len(result), 1)
+
+    def test_hide_home_at_base_url(self):
+        app_settings.DYNAMIC_BREADCRUMBS_SHOW_AT_BASE_PATH = False
+        path = "/"
+        breadcrumbs = Breadcrumbs(path=path)
+
+        result = breadcrumbs.as_list()
+
+        self.assertEqual(len(result), 0)
 
 
 class BreadcrumbsItemTests(GenericModelTestCase):
